@@ -47,7 +47,7 @@ copyright = '2009-2010, Simplon'
 # The short X.Y version.
 version = '2.2'
 # The full version, including alpha/beta/rc tags.
-release = '2.2'
+release = '2.2.1'
 
 # There are two options for replacing |today|: either, you set today to
 # some non-false value, then it is used:
